pub enum OpenIdResolverState {
LoadingConfig,
LoadingJwks {
open_id_response: Arc<OpenIdDiscoveryResponse>,
},
Ready,
}Expand description
The state of the resolver is an enum which has the following variants:
- LoadingConfig: The plugin configuration is being loaded
- LoadingJwks: The jwks configuration is being loaded
- Ready: The plugin is ready
Variants
LoadingConfig
The root context is loading the configuration from the open id discovery endpoint
LoadingJwks
The root context is loading the jwks configuration using the open id configuration
Fields

open_id_response: Arc<OpenIdDiscoveryResponse>response from the config endpoint
Ready
The root context is ready