OpenIdResolver

Struct OpenIdResolver 

pub struct OpenIdResolver {
    pub state: OpenIdResolverState,
    pub open_id_config: OpenIdConfig,
    token_ids: Vec<u32>,
}
A resolver handles the loading of the configuration from the open id discovery endpoint and the jwks endpoint.

Fields

state: OpenIdResolverState

The state of the resolver

open_id_config: OpenIdConfig

The configuration from the plugin configuration

token_ids: Vec<u32>

token_ids of the HttpCalls to verify the call is correct and to determine which response comes in