Root

Struct Root 

pub struct Root {
    pub plugin_config: Option<Arc<V2PluginConfiguration>>,
    pub open_id_resolvers: Vec<OpenIdResolver>,
    pub open_id_providers: Vec<OpenIdProvider>,
    pub waiting: Mutex<Vec<u32>>,
    pub discovery_active: bool,
}
This is the main context which loads and parses the plugin configuration, handles the discovery of all Open ID Providers and creates the HTTP Contexts.

Fields

plugin_config: Option<Arc<V2PluginConfiguration>>

Plugin config loaded from the envoy configuration

open_id_resolvers: Vec<OpenIdResolver>

A set of Open ID Resolvers which are used to load the configuration from the discovery endpoint

open_id_providers: Vec<OpenIdProvider>

A set of Open ID Providers which are used to store the configuration from the discovery endpoint

waiting: Mutex<Vec<u32>>

Queue of waiting requests which are waiting for the configuration to be loaded

discovery_active: bool

Flag to determine if the discovery is active