pub struct OpenIdProvider {
pub open_id_config: OpenIdConfig,
pub auth_endpoint: Url,
pub token_endpoint: Url,
pub end_session_endpoint: Option<Url>,
pub issuer: String,
pub public_keys: Vec<SigningKey>,
}Expand description
The OpenIdProvider struct holds all information about the Open ID Provider that is needed for the plugin to work. This includes the Open ID Configuration, the URLs of the endpoints and the public keys that are used for the validation of the ID Token.
Fields
open_id_config: OpenIdConfigauth_endpoint: UrlThe URL of the authorization endpoint
token_endpoint: UrlThe URL of the token endpoint
end_session_endpoint: Option<Url>The URL of the end session endpoint
issuer: StringThe issuer that will be used for the token request
public_keys: Vec<SigningKey>The public keys that will be used for the validation of the ID Token